# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..utils import ImageInfo


def test_ImageInfo_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        in_file=dict(
            argstr="%s",
            extensions=None,
            position=1,
        ),
        subjects_dir=dict(),
    )
    inputs = ImageInfo.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_ImageInfo_outputs():
    output_map = dict(
        TE=dict(),
        TI=dict(),
        TR=dict(),
        data_type=dict(),
        dimensions=dict(),
        file_format=dict(),
        info=dict(),
        orientation=dict(),
        out_file=dict(
            extensions=None,
        ),
        ph_enc_dir=dict(),
        vox_sizes=dict(),
    )
    outputs = ImageInfo.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
