# AUTO-GENERATED by tools/checkspecs.py - DO NOT EDIT
from ..classify import BRAINSPosteriorToContinuousClass


def test_BRAINSPosteriorToContinuousClass_inputs():
    input_map = dict(
        args=dict(
            argstr="%s",
        ),
        environ=dict(
            nohash=True,
            usedefault=True,
        ),
        inputBasalGmVolume=dict(
            argstr="--inputBasalGmVolume %s",
            extensions=None,
        ),
        inputCrblGmVolume=dict(
            argstr="--inputCrblGmVolume %s",
            extensions=None,
        ),
        inputCrblWmVolume=dict(
            argstr="--inputCrblWmVolume %s",
            extensions=None,
        ),
        inputCsfVolume=dict(
            argstr="--inputCsfVolume %s",
            extensions=None,
        ),
        inputSurfaceGmVolume=dict(
            argstr="--inputSurfaceGmVolume %s",
            extensions=None,
        ),
        inputVbVolume=dict(
            argstr="--inputVbVolume %s",
            extensions=None,
        ),
        inputWhiteVolume=dict(
            argstr="--inputWhiteVolume %s",
            extensions=None,
        ),
        outputVolume=dict(
            argstr="--outputVolume %s",
            hash_files=False,
        ),
    )
    inputs = BRAINSPosteriorToContinuousClass.input_spec()

    for key, metadata in list(input_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(inputs.traits()[key], metakey) == value


def test_BRAINSPosteriorToContinuousClass_outputs():
    output_map = dict(
        outputVolume=dict(
            extensions=None,
        ),
    )
    outputs = BRAINSPosteriorToContinuousClass.output_spec()

    for key, metadata in list(output_map.items()):
        for metakey, value in list(metadata.items()):
            assert getattr(outputs.traits()[key], metakey) == value
